import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ui_sdk/props/ApiResponse.dart';
import 'package:ui_sdk/props/StandardScreenResponse.dart';

class StandardScreenResponseState {
  Map<String, StandardScreenResponse?> responseMap;
  StandardScreenResponseState({this.responseMap = const {},});
}


class StandardScreenResponseCubit extends Cubit<StandardScreenResponseState> {
  StandardScreenResponseCubit() : super(StandardScreenResponseState());

  void updateStandardScreenResponse(String screenReference,
      StandardScreenResponse standardScreenResponse,Map<String, StandardScreenResponse?> oldMap) {
    Future.delayed(const Duration(seconds: 1));
    final updatedMap = Map<String, StandardScreenResponse?>.from(oldMap);
    updatedMap[screenReference] = standardScreenResponse;
    emit(StandardScreenResponseState(
        responseMap: updatedMap,));
  }
}

enum RequestState { initial, loading, loaded, error }

class ApiResponseState {
  final RequestState responseState;
  final bool isPullToRefreshEnabled;
  final Map<String, StandardScreenResponse?> standardScreenResponseMap;
  final ApiResponse? apiResponse;
  final dynamic actionFunction;
  ApiResponseState({
    required this.responseState,
    this.isPullToRefreshEnabled = false,
    Map<String, StandardScreenResponse?>? standardScreenResponseMap,
    this.apiResponse,
    this.actionFunction
  }) : standardScreenResponseMap = standardScreenResponseMap ?? {};
}

class ApiResponseCubit extends Cubit<ApiResponseState> {
  final StandardScreenResponseCubit standardScreenResponseCubit;

  ApiResponseCubit(this.standardScreenResponseCubit)
      : super(ApiResponseState(responseState: RequestState.initial, actionFunction: null));

  void fetchData(
      Future<ApiResponse> Function(Map<dynamic, dynamic>) fetchDataFunction,
      Map<dynamic, dynamic> args,
      String screenReference,
      dynamic fun
      ) async {
    emit(ApiResponseState(responseState: RequestState.loading, actionFunction: fun));
    try {
      final result = await fetchDataFunction(args);
      StandardScreenResponse standardScreenResponse =
      StandardScreenResponse.fromJson(result.data);
      bool pullToRefresh = _isPullToRefreshEnabled(standardScreenResponse);
      Map<String, StandardScreenResponse?> oldMap = standardScreenResponseCubit.state.responseMap;
      standardScreenResponseCubit.updateStandardScreenResponse(
          screenReference, standardScreenResponse,oldMap);

      emit(ApiResponseState(
        responseState: RequestState.loaded,
        isPullToRefreshEnabled: pullToRefresh,
        apiResponse: result,
        actionFunction: fun
      ));
    } catch (e) {
      emit(ApiResponseState(responseState: RequestState.error, actionFunction: fun));
    }
  }

  //todo
  void updatePage() async{
    emit(ApiResponseState(responseState: RequestState.loading));
    await Future.delayed(const Duration(milliseconds: 200));
    emit(ApiResponseState(
      responseState: RequestState.loaded,
      apiResponse: ApiResponse.fromJson(
        {
          "isSuccess": true,
          "data":{}
        }
    )
    ));
  }

  bool _isPullToRefreshEnabled(StandardScreenResponse? standardScreenResponse) {
    try {
      if (standardScreenResponse != null &&
          standardScreenResponse.pageState != null &&
          standardScreenResponse.pageState!
              .containsKey('enablePullToRefresh') &&
          standardScreenResponse.pageState!['enablePullToRefresh'] == true) {
        return true;
      } else {
        return false;
      }
    } catch (e) {
      return false;
    }
  }
}
