import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ui_sdk/props/StandardScreenResponse.dart';

import 'ApiResponseState.dart';
import 'Renderer.dart';
import 'utils/init_data.dart';

abstract class StandardPage {
  late StatefulWidget page;

  dynamic getData();

  Set<String?> getActions();

  dynamic getPageCallBackForAction();

  dynamic getPageContext();

  dynamic getConstructorArgs();

  StandardPage([InitData? args]) {
    page = FlutterPage(
      apiData: getData(),
      actionList: getActions(),
      fun: getPageCallBackForAction(),
      reference: getPageContext(),
      constructorArgs: getConstructorArgs(),
      args: args,
    );
  }

  StatefulWidget getPage() {
    return page;
  }
}

// ignore: must_be_immutable
class FlutterPage extends StatefulWidget {
  final dynamic apiData;
  final Set<String?> actionList;
  final dynamic fun;
  final dynamic reference;
  final dynamic constructorArgs;
  final InitData? args;

  FlutterPage({
    required this.apiData,
    required this.actionList,
    required this.fun,
    required this.reference,
    required this.constructorArgs,
    Key? key,
    this.args,
  }) : super(key: key);

  @override
  State<FlutterPage> createState() => FlutterPageState();
}

class FlutterPageState extends State<FlutterPage> {
  final Renderer renderer = Renderer();
  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addPostFrameCallback((timeStamp) {
      final dynamic args = ModalRoute.of(context)!.settings.arguments ?? {};
      final dynamic constructorArguments = widget.constructorArgs;
      final Map<dynamic, dynamic> finalArgs = {...constructorArguments, ...args};
      final apiCubit = BlocProvider.of<ApiResponseCubit>(context);
      apiCubit.fetchData(widget.apiData, finalArgs, widget.reference,widget.fun);
    });
  }


  Future<void> _handleRefresh() async {
    final apiCubit = BlocProvider.of<ApiResponseCubit>(context);
    final dynamic args = ModalRoute.of(context)!.settings.arguments ?? {};
    final dynamic constructorArguments = widget.constructorArgs;
    final Map<dynamic, dynamic> finalArgs = {...constructorArguments, ...args};
    apiCubit.fetchData(widget.apiData, finalArgs, widget.reference,widget.fun);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: BlocBuilder<ApiResponseCubit, ApiResponseState>(
        builder: (context, apiState) {
          return BlocBuilder<StandardScreenResponseCubit,
              StandardScreenResponseState>(
            builder: (context, standardScreenResponseState) {
              if (apiState.isPullToRefreshEnabled) {
                return RefreshIndicator(
                  color: Colors.yellow,
                  onRefresh: _handleRefresh,
                  child: _buildContent(
                      context, apiState, standardScreenResponseState.responseMap),
                );
              } else {
                return _buildContent(
                    context, apiState, standardScreenResponseState.responseMap);
              }
            },
          );
        },
      ),
    );
  }

  Widget _buildContent(BuildContext context, ApiResponseState apiState,
      Map<String, StandardScreenResponse?> standardScreenResponseMap) {
    if (apiState.responseState == RequestState.loading) {
      return const Center(
        child: CircularProgressIndicator(
          color: Colors.yellow,
        ),
      );
    } else if (apiState.responseState == RequestState.loaded) {
      final response = apiState.apiResponse;
      if (response != null && response.isSuccess == true) {
        final standardScreenResponse =
            standardScreenResponseMap[widget.reference];
        if (standardScreenResponse != null) {
          return renderer.getListWidgetUi(
            standardScreenResponse,
            context,
          );
        } else {
          return const Center(
            child: CircularProgressIndicator(
              color: Colors.yellow,
            ),
          );
        }
      } else {
        return Center(child: Text("++++++Error: ${response?.error}"));
      }
    } else {
      return const Center(child: Text("Failed to load data."));
    }
  }
}
