import 'package:flutter/material.dart';
import 'package:carousel_slider/carousel_slider.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikScrollCarouselProps.dart';

class UikScrollCarousel extends UikWidget {
  WidgetType _widgetType;
  UikScrollCarouselProps _uikScrollCarouselProps;
  UikScrollCarousel(this._widgetType, this._uikScrollCarouselProps)
      : super(_widgetType, _uikScrollCarouselProps);
  @override
  _UikScrollCarouselState createState() =>
      _UikScrollCarouselState(_uikScrollCarouselProps);
}

class _UikScrollCarouselState extends State<UikScrollCarousel> {
  UikScrollCarouselProps _uikScrollCarouselProps;
  _UikScrollCarouselState(this._uikScrollCarouselProps);
  final CarouselController _controller = CarouselController();

  @override
  Widget build(BuildContext context) {
    bool autoScrollEnabled = _uikScrollCarouselProps.autoScrollEnabled;
    bool swipeEnabled = _uikScrollCarouselProps.swipeEnabled;
    bool buttonEnabled = _uikScrollCarouselProps.buttonEnabled;
    return Column(
      children: [
        Container(
          height: _uikScrollCarouselProps.height,
          //decoration: BoxDecoration(border: Border.all()),
          margin: EdgeInsets.only(
            top: _uikScrollCarouselProps.topMargin,
            left: _uikScrollCarouselProps.leftMargin,
            right: _uikScrollCarouselProps.rightMargin,
            bottom: _uikScrollCarouselProps.bottomMargin,
          ),
          child: CarouselSlider(
            items: _uikScrollCarouselProps.widgets,
            options: CarouselOptions(
              viewportFraction: _uikScrollCarouselProps.viewPort,
              scrollDirection: _uikScrollCarouselProps.scrollAxis,
              autoPlay: autoScrollEnabled,
              autoPlayInterval:
                  Duration(seconds: _uikScrollCarouselProps.autoPlayInterval),
              enlargeCenterPage: _uikScrollCarouselProps.enlargeCenter,
              pageSnapping: _uikScrollCarouselProps.pageSnapping,
              enableInfiniteScroll: _uikScrollCarouselProps.infiniteScroll,
              aspectRatio: 16 / 9,
              onPageChanged: (index, reason) {
                // Handle page change if needed
              },
              scrollPhysics: swipeEnabled
                  ? BouncingScrollPhysics()
                  : NeverScrollableScrollPhysics(),
            ),
            carouselController: _controller,
          ),
        ),
        (buttonEnabled)
            ? Row(
                mainAxisAlignment: _uikScrollCarouselProps.buttonAlign,
                children: [
                  SizedBox(
                    width: 20,
                  ),
                  GestureDetector(
                    onTap: () {
                      _controller.previousPage();
                    },
                    child: Container(
                      decoration: BoxDecoration(
                        color: _uikScrollCarouselProps.prevIconbgColor,
                        shape: BoxShape.rectangle,
                        borderRadius: BorderRadius.circular(
                            _uikScrollCarouselProps.prevIconBorderRadius),
                      ),
                      padding: const EdgeInsets.all(8.0),
                      child: Icon(
                        Icons.arrow_back_outlined,
                        size: _uikScrollCarouselProps.prevIconSize,
                        color: _uikScrollCarouselProps.prevIconColor,
                      ),
                    ),
                  ),
                  SizedBox(
                    width: 20,
                  ),
                  GestureDetector(
                    onTap: () {
                      _controller.nextPage();
                    },
                    child: Container(
                      decoration: BoxDecoration(
                        color: _uikScrollCarouselProps.nextIconbgColor,
                        shape: BoxShape.rectangle,
                        borderRadius: BorderRadius.circular(
                            _uikScrollCarouselProps.nextIconBorderRadius),
                      ),
                      padding: const EdgeInsets.all(8.0),
                      child: Icon(
                        Icons.arrow_forward_outlined,
                        size: _uikScrollCarouselProps.nextIconSize,
                        color: _uikScrollCarouselProps.nextIconColor,
                      ),
                    ),
                  ),
                  SizedBox(
                    width: 20,
                  ),
                ],
              )
            : SizedBox(),
      ],
    );
  }
}
