import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikJobBoxProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';

class UikJobBox extends UikWidget {
  WidgetType _widgetType;
  UikJobBoxProps _UikJobBoxProps;
  UikJobBox(this._widgetType, this._UikJobBoxProps)
      : super(_widgetType, _UikJobBoxProps);

  @override
  State<UikJobBox> createState() => _UikJobBoxState(_UikJobBoxProps);
}

class _UikJobBoxState extends State<UikJobBox> {
  UikJobBoxProps _uikJobBoxProps;
  _UikJobBoxState(this._uikJobBoxProps);
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.fromLTRB(
        _uikJobBoxProps.leftMargin,
        _uikJobBoxProps.topMargin,
        _uikJobBoxProps.rightMargin,
        _uikJobBoxProps.bottomMargin,
      ),
      child: Material(
        elevation: _uikJobBoxProps.elevation,
        borderRadius: BorderRadius.circular(_uikJobBoxProps.borderRadius),
        child: Stack(
          children: [
            Column(
              children: [
                Container(
                  padding: EdgeInsets.symmetric(vertical: 8),
                  width: double.maxFinite,
                  decoration: BoxDecoration(
                    border: Border(
                      top: BorderSide(
                        color: _uikJobBoxProps.upperBorderColor,
                        width: _uikJobBoxProps.borderWidth,
                      ),
                      left: BorderSide(
                        color: _uikJobBoxProps.upperBorderColor,
                        width: _uikJobBoxProps.borderWidth,
                      ),
                      right: BorderSide(
                        color: _uikJobBoxProps.upperBorderColor,
                        width: _uikJobBoxProps.borderWidth,
                      ),
                    ),
                    gradient: LinearGradient(
                      //  colors: [Colors.yellow.shade400, Colors.yellow.shade100],
                      colors: _uikJobBoxProps.gradient,
                      begin: Alignment.topRight,
                      end: Alignment.bottomLeft,
                    ),
                    borderRadius: BorderRadius.only(
                      topLeft: Radius.circular(_uikJobBoxProps.borderRadius),
                      topRight: Radius.circular(_uikJobBoxProps.borderRadius),
                    ),
                  ),
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      _buildProfileInfo(),
                      _buildWrapContainer(),
                    ],
                  ),
                ),
                _buildContent(),
              ],
            ),
            Positioned(
              child: _buildUrgentHiringLabel(),
              right: 0,
              top: 30,
            )
          ],
        ),
      ),
    );
  }

  Widget _buildProfileInfo() {
    return Container(
      padding: EdgeInsets.only(left: 14, top: 15),
      child: Row(
        //    mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          CircleAvatar(
            radius: 30,
            backgroundColor: Colors.amber[300],
            foregroundImage: (_uikJobBoxProps.image != null)
                ? NetworkImage(_uikJobBoxProps.image!)
                : null,
            child: Text(
              _uikJobBoxProps.companyNamefirstText,
              textAlign: TextAlign.center,
              style: TextStyle(color: Colors.yellowAccent, fontSize: 40),
            ),
          ),
          SizedBox(width: 8),
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              (_uikJobBoxProps.jobName != null)
                  ? _uikJobBoxProps.jobName!
                  : Container(),
              (_uikJobBoxProps.companyText != null)
                  ? _uikJobBoxProps.companyText!
                  : Container(),
            ],
          ),
        ],
      ),
    );
  }

  Widget _buildUrgentHiringLabel() {
    return (_uikJobBoxProps.isUrgentHiring)
        ? Container(
            padding: EdgeInsets.all(5),
            decoration: BoxDecoration(
              color: Colors.white,
              borderRadius: BorderRadius.only(
                topLeft: Radius.circular(8),
                bottomLeft: Radius.circular(8),
              ),
            ),
            child: Text(
              "Urgent hiring",
              style: GoogleFonts.poppins(
                fontWeight: FontWeight.w600,
                color: Colors.red,
              ),
            ),
          )
        : Container();
  }

  Widget _buildWrapContainer() {
    return Container(
      width: double.maxFinite,
      padding: EdgeInsets.all(15),
      child: Wrap(
        spacing: 15,
        children: buildTagWidgets(),
      ),
    );
  }

  List<Widget> buildTagWidgets() {
    return _uikJobBoxProps.tag.map((tag) {
      return _buildContainer(tag.icon, tag.text, tag.bgColor);
    }).toList();
  }

  Widget _buildContainer(Widget? icon, Widget? text, Color bgColor) {
    return (text != null)
        ? Container(
            padding: EdgeInsets.symmetric(horizontal: 12, vertical: 5),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(100),
              color: bgColor,
            ),
            child: Row(
              mainAxisSize: MainAxisSize.min,
              children: [
                (icon != null) ? icon : SizedBox(),
                text,
              ],
            ),
          )
        : Container();
  }

  Widget _buildContent() {
    return Container(
      width: double.maxFinite,
      padding: EdgeInsets.symmetric(horizontal: 15, vertical: 8),
      decoration: BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.only(
          bottomLeft: Radius.circular(8),
          bottomRight: Radius.circular(8),
        ),
      ),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          _buildSalaryText(),
          _buildViewDetailsText(),
        ],
      ),
    );
  }

  Widget _buildSalaryText() {
    if (_uikJobBoxProps.salary != null) {
      return _uikJobBoxProps.salary!;
    }
    return Container();
  }

  Widget _buildViewDetailsText() {
    return InkWell(
      onTap: () {
        executeUikWidgetAction(_uikJobBoxProps.action, context);
      },
      child: Text(
        "View Details",
        style: GoogleFonts.poppins(
          color: Colors.blue,
          fontSize: 15,
          fontWeight: FontWeight.w600,
        ),
      ),
    );
  }
}
