import 'package:flutter/material.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikJobProps.dart';
import 'package:ui_sdk/props/WidgetProps.dart';

class UikJob extends UikWidget {
  WidgetType _widgetType;
  UikJobProps _UikJobProps;
  UikJob(this._widgetType, this._UikJobProps)
      : super(_widgetType, _UikJobProps);

  @override
  State<UikJob> createState() => _UikJobState(_UikJobProps);
}

class _UikJobState extends State<UikJob> {
  UikJobProps _uikJobProps;
  _UikJobState(this._uikJobProps);
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(8.0), //8.0
      child: Material(
        elevation: _uikJobProps.elevation, //4.0
        borderRadius: BorderRadius.circular(_uikJobProps.borderRadius), //10
        child: Container(
          // decoration: BoxDecoration(
          //   border: Border.all(width: 0.3),
          //   borderRadius: BorderRadius.circular(10),
          // ),
          padding: EdgeInsets.all(8),
          width: double.maxFinite,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Expanded(
                    flex: 1,
                    child: Container(
                      width: 100,
                      height: 90,
                      color: Colors.black45,
                      child: (_uikJobProps.image != null)
                          ? Image.network(
                              _uikJobProps.image!,
                            )
                          : Text(
                              "${_uikJobProps.companyText[0]}",
                              textAlign: TextAlign.center,
                              style: TextStyle(
                                  color: Colors.yellowAccent, fontSize: 30),
                            ),
                    ),
                  ),
                  Expanded(
                    flex: 3,
                    child: Padding(
                      padding: const EdgeInsets.only(left: 5),
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Row(
                            children: [
                              Text(
                                _uikJobProps.jobNameText,
                                style: TextStyle(
                                  fontSize: 15,
                                  fontWeight: FontWeight.w700,
                                  color: Colors.blue,
                                ),
                              ),
                              Icon(
                                Icons.keyboard_double_arrow_right_sharp,
                                color: Colors.blueAccent,
                              ),
                            ],
                          ),
                          Text(
                            _uikJobProps.companyText,
                            style: TextStyle(
                              fontSize: 15,
                              fontWeight: FontWeight.w700,
                            ),
                          ),
                          Text(
                            _uikJobProps.descriptionText,
                            maxLines: 2,
                            overflow: TextOverflow.ellipsis,
                            style: TextStyle(
                              fontSize: 15,
                              color: Colors.grey,
                            ),
                          ),
                          (_uikJobProps.startRange == 0 &&
                                  _uikJobProps.endRange == null)
                              ? Container()
                              : (_uikJobProps.startRange != 0 &&
                                      _uikJobProps.endRange == null)
                                  ? Text(
                                      "\$0-\$${_uikJobProps.startRange}",
                                      style: TextStyle(
                                        fontSize: 15,
                                        color: Colors.green,
                                        fontWeight: FontWeight.w700,
                                      ),
                                    )
                                  : Text(
                                      "\$${_uikJobProps.startRange}-\$${_uikJobProps.endRange}",
                                      style: TextStyle(
                                        fontSize: 15,
                                        color: Colors.green,
                                        fontWeight: FontWeight.w700,
                                      ),
                                    ),
                        ],
                      ),
                    ),
                  ),
                  InkWell(
                    child: Icon(
                      Icons.favorite_border,
                    ),
                  ),
                ],
              ),
              Container(
                margin: EdgeInsets.all(8),
                padding: EdgeInsets.symmetric(horizontal: 8, vertical: 5),
                decoration: BoxDecoration(
                  color: Colors.blue[100],
                  borderRadius: BorderRadius.all(Radius.circular(20)),
                ),
                child: (_uikJobProps.vacantSeat == null)
                    ? null
                    : Text(
                        "${_uikJobProps.vacantSeat} vacancies",
                        style: TextStyle(
                            fontSize: 13,
                            fontWeight: FontWeight.w700,
                            color: const Color.fromARGB(255, 0, 120, 218)),
                      ),
              ),
              Container(
                //   margin: EdgeInsets.only(bottom: 8),
                width: 380,
                height: 1,
                color: Colors.grey,
              ),
              Row(
                children: [
                  Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Row(
                        children: [
                          Icon(
                            Icons.location_on,
                            color: Colors.grey[800],
                          ),
                          Text(
                            _uikJobProps.locationText,
                            style: TextStyle(
                              fontSize: 16,
                              color: Colors.grey[700],
                              fontWeight: FontWeight.w500,
                            ),
                          ),
                        ],
                      ),
                      Row(
                        children: [
                          Icon(
                            Icons.badge_rounded,
                            color: Colors.grey[800],
                          ),
                          Text(
                            _uikJobProps.experienceText,
                            style: TextStyle(
                              fontSize: 16,
                              color: Colors.grey[700],
                              fontWeight: FontWeight.w500,
                            ),
                          ),
                        ],
                      ),
                    ],
                  ),
                  Padding(
                    padding: const EdgeInsets.only(left: 40),
                    child: Row(
                      children: [
                        Container(
                          margin: EdgeInsets.all(8),
                          width: 1.5,
                          height: 50,
                          color: Colors.grey,
                        ),
                        Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Row(
                              children: [
                                Icon(
                                  Icons.watch_later_outlined,
                                  color: Colors.grey[800],
                                ),
                                Text(
                                  _uikJobProps.jobTypeText,
                                  style: TextStyle(
                                    fontSize: 16,
                                    color: Colors.grey[700],
                                    fontWeight: FontWeight.w500,
                                  ),
                                ),
                              ],
                            ),
                            Row(
                              children: [
                                Icon(
                                  Icons.menu_book,
                                  color: Colors.grey[800],
                                ),
                                Text(
                                  _uikJobProps.educationText,
                                  style: TextStyle(
                                    fontSize: 16,
                                    color: Colors.grey[700],
                                    fontWeight: FontWeight.w500,
                                  ),
                                ),
                              ],
                            ),
                          ],
                        ),
                      ],
                    ),
                  ),
                ],
              ),
              Container(
                width: 380,
                height: 1,
                color: Colors.grey,
              ),
              Padding(
                padding: const EdgeInsets.only(top: 8),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Icon(
                      Icons.menu,
                      size: 40,
                    ),
                    SizedBox(
                      width: 10,
                    ),
                    InkWell(
                      child: Container(
                        width: 340,
                        height: 40,
                        decoration: BoxDecoration(
                            color: Colors.orangeAccent[400],
                            borderRadius: BorderRadius.circular(8)),
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: [
                            Icon(
                              Icons.call,
                              color: Colors.grey,
                            ),
                            Text(
                              "Call HR",
                              style: TextStyle(
                                fontSize: 16,
                                // color: Colors.grey[700],
                                fontWeight: FontWeight.w700,
                              ),
                            ),
                          ],
                        ),
                      ),
                    )
                  ],
                ),
              )
            ],
          ),
        ),
      ),
    );
  }
}
